package com.atlassian.jira.plugin.customfield.example;

import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.Set;

import org.ofbiz.core.entity.GenericEntityException;
import org.ofbiz.core.entity.GenericValue;

import com.atlassian.jira.issue.ActionManager;
import com.atlassian.jira.issue.action.Comment;
import com.atlassian.jira.issue.customfields.converters.UserConverter;
import com.atlassian.jira.issue.customfields.impl.AbstractCustomFieldType;
import com.atlassian.jira.issue.customfields.impl.CustomFieldValidationException;
import com.atlassian.jira.issue.customfields.view.CustomFieldParams;
import com.atlassian.jira.issue.customfields.SortableCustomField;
import com.atlassian.jira.issue.fields.CustomField;
import com.atlassian.jira.security.JiraAuthenticationContext;
import com.atlassian.jira.util.ErrorCollection;
import com.atlassian.core.user.BestNameComparator;
import com.opensymphony.user.User;

public class LastUserCommentedCFType extends AbstractCustomFieldType implements SortableCustomField
{
    private final UserConverter userConverter;
    private final ActionManager actionManager;
    private final JiraAuthenticationContext authenticationContext;
    static final String JIRA_ADMIN = "jira-administrators";


    public LastUserCommentedCFType(UserConverter userConverter, ActionManager actionManager, JiraAuthenticationContext authenticationContext)
    {
        this.userConverter = userConverter;
        this.actionManager = actionManager;
        this.authenticationContext = authenticationContext;
    }
    
    public String getStringFromSingularObject(Object value)
    {
        assertObjectImplementsType(User.class, value);
        return userConverter.getString((User) value);
    }

    public Object getSingularObjectFromString(String string) throws CustomFieldValidationException
    {
        return userConverter.getUser(string);
    }
    
    public Set remove(CustomField field)
    {
        return Collections.EMPTY_SET;
    }

    public void validateFromParams(CustomFieldParams relevantParams, ErrorCollection errorCollectionToAddTo)
    {
        // Do nothing
    }

    public void createValue(CustomField field, GenericValue issue, Object value)
    {
        // Do nothing
    }

    public void updateValue(CustomField field, GenericValue issue, Object value)
    {
        // Do nothing
    }

    public void removeValue(CustomField arg0, GenericValue arg1, Object arg2)
    {
        // Do nothing
    }

    public Object getValueFromCustomFieldParams(CustomFieldParams parameters) throws CustomFieldValidationException
    {
        Object o = parameters.getFirstValueForKey(null);
        User user = (User) getSingularObjectFromString((String)o);
        
        return user;
    }

    public Object getValueFromIssue(CustomField field, GenericValue issue)
    {
        User currentUser = authenticationContext.getUser(); 
        User lastUser = null;
        try
        {
            List comments = actionManager.getComments(issue, currentUser);
            if (comments != null && !comments.isEmpty())
            {
                Comment lastComment = (Comment) comments.get(comments.size()-1);
                User commenter = lastComment.getUser();
                if (!commenter.inGroup(JIRA_ADMIN))
                {
                    lastUser = commenter;
                }
            }
        }
        catch (GenericEntityException e)
        {
        }
        
        return lastUser;
    }

    public Object getDefaultValue(CustomField field)
    {
        return null;
    }

    public void setDefaultValue(CustomField field, Object value)
    {
        // Do nothing
    }

    public String getChangelogValue(CustomField field, Object value)
    {
        return "";
    }

    public int compare(Object customFieldObjectValue1, Object customFieldObjectValue2)
    {
        return new BestNameComparator().compare(customFieldObjectValue1, customFieldObjectValue2);
    }
}
